@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -44,7 +44,7 @@ switch ($action) {
 		// If the user is not logged in, redirect them to the login page
 		if (!isset($_SESSION['sess_user_id'])) {
 			if (isset($_SERVER['HTTP_REFERER'])) {
-				header('Location: ' . sanitize_uri($_SERVER['HTTP_REFERER']));
+				header('Location: ' . $_SERVER['HTTP_REFERER']);
 			} else {
 				header('Location: index.php');
 			}
@@ -69,7 +69,7 @@ if (!cacti_sizeof($user) || $user['realm'] != 0) {
 	}
 
 	if (isset($_SERVER['HTTP_REFERER'])) {
-		header('Location: ' . sanitize_uri($_SERVER['HTTP_REFERER']));
+		header('Location: ' . $_SERVER['HTTP_REFERER']);
 	} else {
 		header('Location: index.php');
 	}
@@ -82,11 +82,10 @@ if ($user['password_change'] != 'on') {
 
 	/* destroy session information */
 	kill_session_var('sess_user_id');
-	unset($_COOKIE[$cacti_session_name]);
-	setcookie($cacti_session_name, null, -1, $config['url_path']);
+	cacti_cookie_logout();
 
 	if (isset($_SERVER['HTTP_REFERER'])) {
-		header('Location: ' . sanitize_uri($_SERVER['HTTP_REFERER']));
+		header('Location: ' . $_SERVER['HTTP_REFERER']);
 	} else {
 		header('Location: index.php');
 	}
@@ -203,6 +202,32 @@ case 'changepassword':
 			WHERE id = ?",
 			array(compat_password_hash($password,PASSWORD_DEFAULT), $user_id));
 
+		// Clear the auth cache for the user
+		$token = '';
+		if (isset($_SERVER['HTTP_COOKIE']) && strpos($_SERVER['HTTP_COOKIE'], 'cacti_remembers') !== false) {
+			$parts = explode(';', $_SERVER['HTTP_COOKIE']);
+			foreach($parts as $p) {
+				if (strpos($p, 'cacti_remembers') !== false) {
+					$pparts = explode('%2C', $p);
+					if (isset($pparts[1])) {
+						$token = $pparts[1];
+						break;
+					}
+				}
+			}
+		}
+
+		if ($token != '') {
+			$sql_where = 'AND token != ' . db_qstr(hash('sha512', $token, false));
+		} else {
+			$sql_where = '';
+		}
+
+		db_execute_prepared("DELETE FROM user_auth_cache
+			WHERE user_id = ?
+			$sql_where",
+			array($_SESSION['sess_user_id']));
+
 		kill_session_var('sess_change_password');
 
 		raise_message('password_success');
@@ -312,25 +337,22 @@ if ($skip_current) {
 				</div>
 				<div class='cactiLogin'>
 					<table class='cactiLoginTable'>
-						<tr style='display:none'>
-							<td><input type='text'><input type='password'></td>
-						</tr>
 						<tr>
 <?php if ($skip_current) { ?>
 							<td><?php print __('Username');?></td>
-							<td class='nowrap'><input type='hidden' id='current' name='current_password' value=''><?php print $user['username'];?></td>
+							<td class='nowrap'><input type='hidden' id='current' name='current_password' autocomplete='current-password' value=''><?php print $user['username'];?></td>
 <?php } else { ?>
 							<td><?php print __('Current password');?></td>
-							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='current' name='current_password' autocomplete='off' size='20' placeholder='********'></td>
+							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='current' name='current_password' autocomplete='current-passowrd' size='20' placeholder='********'></td>
 <?php } ?>
 						</tr>
 						<tr>
 							<td><?php print __('New password');?></td>
-							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='password' name='password' autocomplete='off' size='20' placeholder='********'><?php display_tooltip($secpass_tooltip);?></td>
+							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='password' name='password' autocomplete='new-password' size='20' placeholder='********'><?php print display_tooltip($secpass_tooltip);?></td>
 						</tr>
 						<tr>
 							<td><?php print __('Confirm new password');?></td>
-							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='password_confirm' name='password_confirm' autocomplete='off' size='20' placeholder='********'></td>
+							<td class='nowrap'><input type='password' class='ui-state-default ui-corner-all' id='password_confirm' name='password_confirm' autocomplete='new-password' size='20' placeholder='********'></td>
 						</tr>
 						<tr>
 							<td class='nowrap' colspan='2'><input type='submit' class='ui-button ui-corner-all ui-widget' value='<?php print __esc('Save'); ?>'>
