@@ -1333,7 +1333,7 @@ function item() {
 	} else {
 		$template_item_list = db_fetch_assoc_prepared("SELECT
 			gti.id, gti.text_format, gti.value, gti.hard_return, gti.graph_type_id, gti.alpha, gti.textalign,
-			gti.consolidation_function_id,
+			gti.consolidation_function_id, gti.sequence,
 			CONCAT(dtd.name_cache, ' (',  dtr.data_source_name, ')') AS data_source_name,
 			cd.name AS cdef_name, c.hex,
 			vd.name AS vdef_name, gtgp.name AS gprint_name
@@ -2274,4 +2274,3 @@ function graph_management() {
 
 	form_end();
 }
-
