@@ -85,12 +85,24 @@ function install_create_csrf_secret($file) {
 function install_test_local_database_connection() {
 	global $database_type, $database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_retries, $database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca;
 
-	if (!isset($database_ssl)) $database_ssl = false;
-	if (!isset($database_ssl_key)) $database_ssl_key = false;
+	if (!isset($database_ssl))      $database_ssl      = false;
+	if (!isset($database_ssl_key))  $database_ssl_key  = false;
 	if (!isset($database_ssl_cert)) $database_ssl_cert = false;
-	if (!isset($database_ssl_ca)) $database_ssl_ca = false;
+	if (!isset($database_ssl_ca))   $database_ssl_ca   = false;
 
-	$connection = db_connect_real($database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_retries, $database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca);
+	$connection = db_connect_real(
+		$database_hostname,
+		$database_username,
+		$database_password,
+		$database_default,
+		$database_type,
+		$database_port,
+		$database_retries,
+		$database_ssl,
+		$database_ssl_key,
+		$database_ssl_cert,
+		$database_ssl_ca
+	);
 
 	if (is_object($connection)) {
 		db_close($connection);
@@ -103,12 +115,24 @@ function install_test_local_database_connection() {
 function install_test_remote_database_connection() {
 	global $rdatabase_type, $rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $rdatabase_retries, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca;
 
-	if (!isset($rdatabase_ssl)) $rdatabase_ssl = false;
-	if (!isset($rdatabase_ssl_key)) $rdatabase_ssl_key = false;
+	if (!isset($rdatabase_ssl))      $rdatabase_ssl      = false;
+	if (!isset($rdatabase_ssl_key))  $rdatabase_ssl_key  = false;
 	if (!isset($rdatabase_ssl_cert)) $rdatabase_ssl_cert = false;
-	if (!isset($rdatabase_ssl_ca)) $rdatabase_ssl_ca = false;
+	if (!isset($rdatabase_ssl_ca))   $rdatabase_ssl_ca   = false;
 
-	$connection = db_connect_real($rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $rdatabase_retries, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca);
+	$connection = db_connect_real(
+		$rdatabase_hostname,
+		$rdatabase_username,
+		$rdatabase_password,
+		$rdatabase_default,
+		$rdatabase_type,
+		$rdatabase_port,
+		$rdatabase_retries,
+		$rdatabase_ssl,
+		$rdatabase_ssl_key,
+		$rdatabase_ssl_cert,
+		$rdatabase_ssl_ca
+	);
 
 	if (is_object($connection)) {
 		db_close($connection);
@@ -726,18 +750,30 @@ function install_file_paths() {
 
 function remote_update_config_file() {
 	global $config, $rdatabase_type, $rdatabase_hostname, $rdatabase_username,
-		$rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, 
+		$rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $rdatabase_retries,
 		$rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca;
 
 	global $database_type, $database_hostname, $database_username,
-		$database_password, $database_default, $database_type, $database_port, 
+		$database_password, $database_default, $database_type, $database_port, $database_retries,
 		$database_ssl, $database_ssl_key, $database_ssl_cert, $database_ssl_ca;
 
 	$failure     = '';
 	$newfile     = array();
 	$config_file = $config['base_path'] . '/include/config.php';
 
-	$connection = db_connect_real($rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca);
+	$connection = db_connect_real(
+		$rdatabase_hostname,
+		$rdatabase_username,
+		$rdatabase_password,
+		$rdatabase_default,
+		$rdatabase_type,
+		$rdatabase_port,
+		$rdatabase_retries,
+		$rdatabase_ssl,
+		$rdatabase_ssl_key,
+		$rdatabase_ssl_cert,
+		$rdatabase_ssl_ca
+	);
 
 	if (is_object($connection)) {
 		if (function_exists('gethostname')) {
@@ -760,6 +796,7 @@ function remote_update_config_file() {
 			$save['dbuser']    = $database_username;
 			$save['dbpass']    = $database_password;
 			$save['dbport']    = $database_port;
+			$save['dbretries'] = $database_retries;
 			$save['dbssl']     = $database_ssl ? 'on' : '';
 			$save['dbsslkey']  = $database_ssl_key;
 			$save['dbsslcert'] = $database_ssl_cert;
