@@ -91,9 +91,23 @@ function update_data_source_title_cache_from_host($host_id, $query_id = 0, $ids
 /* update_data_source_title_cache - updates the title cache for a single data source
    @arg $local_data_id - (int) the ID of the data source to update the title cache for */
 function update_data_source_title_cache($local_data_id) {
+	$old_title = db_fetch_cell_prepared('SELECT name_cache
+		FROM data_template_data
+		WHERE local_data_id = ?',
+		array($local_data_id));
+	
 	$data_source = get_data_source_title($local_data_id);
 
-	if (strstr($data_source, '|query_') === false && strstr($data_source, '|host_') === false) {
+	if (strstr($data_source, '|query_') !== false || strstr($data_source, '|host_') !== false) {
+		if ($old_title == '') {
+			db_execute_prepared('UPDATE data_template_data
+				SET name_cache = ?
+				WHERE local_data_id = ?',
+				array($data_source, $local_data_id));
+
+			api_plugin_hook_function('update_data_source_title_cache', $local_data_id);
+		}
+	} else {
 		db_execute_prepared('UPDATE data_template_data
 			SET name_cache = ?
 			WHERE local_data_id = ?',
