@@ -1,8 +1,8 @@
-#!/usr/bin/php -q
+#!/usr/bin/env php
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -137,7 +137,7 @@ if (cacti_sizeof($poller_commands)) {
 			}
 
 			if ($first_host) {
-				cacti_log("Device[$device_id] WARNING: Recache Event Detected for Device", true, 'PCOMMAND');
+				cacti_log("Device[$device_id] NOTE: Recache Event Detected for Device", true, 'PCOMMAND');
 			}
 
 			cacti_log("Device[$device_id] DQ[$data_query_id] RECACHE: Recache for Device started.", true, 'PCOMMAND', $verbosity);
