@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2021 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -486,6 +486,7 @@ function form_save() {
 	if (isset_request_var('save_component_tree')) {
 		/* ================= input validation ================= */
 		get_filter_request_var('id');
+		get_filter_request_var('sequence');
 		/* ==================================================== */
 
 		if (get_filter_request_var('id') > 0) {
@@ -504,8 +505,10 @@ function form_save() {
 		$save['enabled']       = get_nfilter_request_var('enabled') == 'true' ? 'on':'-';
 		$save['modified_by']   = $_SESSION['sess_user_id'];
 
-		if (empty($save['sequence'])) {
+		if (isempty_request_var('sequence')) {
 			$save['sequence'] = tree_get_max_sequence() + 1;
+		} else {
+			$save['sequence'] = get_request_var('sequence');
 		}
 
 		if (empty($save['id'])) {
@@ -1064,7 +1067,7 @@ function tree_edit() {
 				event.preventDefault();
 
 				if ($(this).attr('id') == 'tree_edit') {
-					$.post('tree.php', { action: 'save', name: $('#name').val(), sort_type: $('#sort_type').val(), enabled: $('#enabled').is(':checked'), id: $('#id').val(), save_component_tree: 1, __csrf_magic: csrfMagicToken } ).done(function(data) {
+					$.post('tree.php', { action: 'save', name: $('#name').val(), sort_type: $('#sort_type').val(), enabled: $('#enabled').is(':checked'), id: $('#id').val(), save_component_tree: 1, sequence: $('#sequence').val(), __csrf_magic: csrfMagicToken } ).done(function(data) {
 						$('#main').html(data);
 						applySkin();
 					});
@@ -1785,7 +1788,7 @@ function display_graphs() {
 		$sql_where .= ($sql_where != '' ? ' AND ': 'WHERE ') . 'h.site_id = ' . get_request_var('site_id');
 	}
 
-	if (get_request_var('host_id') != '') {
+	if (get_filter_request_var('host_id') != '') {
 		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . 'gl.host_id = ' . get_request_var('host_id');
 	}
 
@@ -1981,7 +1984,7 @@ function tree() {
 		$sql_order
 		$sql_limit");
 
-	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT(ti.graph_tree_id))
+	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT(t.id))
 		FROM graph_tree AS t
 		LEFT JOIN graph_tree_items AS ti
 		ON t.id=ti.graph_tree_id
